==> InfiniTec.Exchange_0.96_Source.zip: Connection.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Net;
using InfiniTec.Threading;
using InfiniTec.Exchange.WebDav;
using InfiniTec.Exchange.WebDav.Request;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information used to access the Exchange store.
    /// </summary>
    public class Connection
    {
        private CookieCollection _FBACache;
        private string _Server;
        private ConnectionProtocol _ConnectionProtocol;
        private Credential _Credential;

        internal CookieCollection FBACache
        {
            get { return _FBACache; }
            set { _FBACache = value; }
        }

        private Uri BaseUrl
        {
            get
            {
                string prefix;

                switch (ConnectionProtocol)
                {
                    case ConnectionProtocol.Default: prefix = "http"; break;
                    case ConnectionProtocol.Secure: prefix = "https"; break;
                    default: throw new NotSupportedException("The specified protocol type (" + ConnectionProtocol.ToString() + ") is not supported.");
                }
                return new Uri(string.Format("{0}://{1}", prefix, Server));
            }
        }

        /// <summary>
        /// Gets or sets the DNS name of the Exchange server.
        /// </summary>
        public string Server
        {
            get { return _Server; }
            set { _Server = value; }
        }

        /// <summary>
        /// Gets or sets the <see cref="ConnectionProtocol"/> to use
        /// for requests.
        /// </summary>
        public ConnectionProtocol ConnectionProtocol
        {
            get { return _ConnectionProtocol; }
            set { _ConnectionProtocol = value; }
        }

        /// <summary>
        /// Gets or sets the <see cref="Credential"/> used for requests.
        /// </summary>
        public Credential Credential
        {
            get { return _Credential; }
            set { _Credential = value; }
        }

        /// <summary>
        /// Creates a new <see cref="RequestOperation"/> configured with
        /// the specified <see cref="RequestSettings"/>.
        /// </summary>
        /// <param name="requestInfo">The settings for the request.</param>
        /// <returns>A <see cref="RequestOperation"/>.</returns>
        public RequestOperation CreateRequest(RequestSettings requestInfo)
        {
            return Request.Create(requestInfo, this);
        }

        /// <summary>
        /// Creates a full qualified url based on the current connection 
        /// settings and the provided relative path.
        /// </summary>
        /// <param name="path">The relative url on the Exchange server.</param>
        /// <returns>An <see cref="Uri"/> for the requested path.</returns>
        public Uri CreateUrl(string path)
        {
            if (path.StartsWith("/")) path = path.Substring(1);

            return new Uri(BaseUrl, path);
        }

        /// <summary>
        /// Checks the specified url it matches the specified <see cref="ConnectionProtocol"/> and
        /// server.
        /// </summary>
        /// <param name="url">The url to check.</param>
        /// <returns>True, if the url can be handled by the current <see cref="Connection"/> instance. False, otherwise.</returns>
        public bool IsValidUrl(Uri url)
        {
            return BaseUrl.IsBaseOf(url);
        }

        /// <summary>
        /// Creates a new instance of this class using the specified settings.
        /// </summary>
        /// <param name="server">The DNS name or IP-Address of the Exchange server.</param>
        /// <param name="protocol">The <see cref="ConnectionProtocol"/> to use.</param>
        /// <param name="credential">The <see cref="Credential"/> to use.</param>
        public Connection(string server, ConnectionProtocol protocol, Credential credential)
        {
            _Server = server;
            _ConnectionProtocol = protocol;
            _Credential = credential;
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        public Connection()
        {
            Credential = new Credential();
        }
    }
}

==> InfiniTec.Exchange_0.97_Source.zip: Connection.cs <==
using System;
using System.Collections.Generic;
using System.Net;
using InfiniTec.Exchange.WebDav.Request;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information used to access the Exchange store.
    /// </summary>
    public class Connection
    {
        private CookieCollection _FBACache;
        private string _Server;
        private ConnectionProtocol _ConnectionProtocol;
        private Credential _Credential;
        private List<IPAddress> _DnsEntries;

        internal CookieCollection FBACache
        {
            get { return _FBACache; }
            set { _FBACache = value; }
        }

        private Uri BaseUrl
        {
            get
            {
                string prefix;

                switch (ConnectionProtocol)
                {
                    case ConnectionProtocol.Default: prefix = "http"; break;
                    case ConnectionProtocol.Secure: prefix = "https"; break;
                    default: throw new NotSupportedException("The specified protocol type (" + ConnectionProtocol + ") is not supported.");
                }
                return new Uri(string.Format("{0}://{1}", prefix, Server));
            }
        }

        /// <summary>
        /// Gets or sets the DNS name of the Exchange server.
        /// </summary>
        public string Server
        {
            get { return _Server; }
            set
            {
                _DnsEntries = GetIPAddresses(value);
                _Server = value;
            }
        }

        private static List<IPAddress> GetIPAddresses(string value)
        {
            IPAddress address;
            List<IPAddress> result;

            result = new List<IPAddress>();

            if (IPAddress.TryParse(value, out address))
            {
                result.Add(address);
            }
            else
            {
                result.AddRange(Dns.GetHostAddresses(value));
            }

            return result;
        }

        /// <summary>
        /// Gets or sets the <see cref="ConnectionProtocol"/> to use
        /// for requests.
        /// </summary>
        public ConnectionProtocol ConnectionProtocol
        {
            get { return _ConnectionProtocol; }
            set { _ConnectionProtocol = value; }
        }

        /// <summary>
        /// Gets or sets the <see cref="Credential"/> used for requests.
        /// </summary>
        public Credential Credential
        {
            get { return _Credential; }
            set { _Credential = value; }
        }

        /// <summary>
        /// Creates a new <see cref="RequestOperation"/> configured with
        /// the specified <see cref="RequestSettings"/>.
        /// </summary>
        /// <param name="requestInfo">The settings for the request.</param>
        /// <returns>A <see cref="RequestOperation"/>.</returns>
        public RequestOperation CreateRequest(RequestSettings requestInfo)
        {
            return Request.Create(requestInfo, this);
        }

        /// <summary>
        /// Creates a full qualified url based on the current connection 
        /// settings and the provided relative path.
        /// </summary>
        /// <param name="path">The relative url on the Exchange server.</param>
        /// <returns>An <see cref="Uri"/> for the requested path.</returns>
        public Uri CreateUrl(string path)
        {
            if (path.StartsWith("/")) path = path.Substring(1);

            return new Uri(BaseUrl, path);
        }

        /// <summary>
        /// Checks the specified url it matches the specified <see cref="ConnectionProtocol"/> and
        /// server.
        /// </summary>
        /// <param name="url">The url to check.</param>
        /// <returns>True, if the url can be handled by the current <see cref="Connection"/> instance. False, otherwise.</returns>
        public bool IsValidUrl(Uri url)
        {
            List<IPAddress> addresses;

            addresses = GetIPAddresses(url.Host);

            foreach (IPAddress serverAddress in _DnsEntries)
            {
                foreach (IPAddress urlAddress in addresses)
                {
                    if (serverAddress.Equals(urlAddress)) return true;
                }
            }

            return false;
        }

        /// <summary>
        /// Creates a new instance of this class using the specified settings.
        /// </summary>
        /// <param name="server">The DNS name or IP-Address of the Exchange server.</param>
        /// <param name="protocol">The <see cref="ConnectionProtocol"/> to use.</param>
        /// <param name="credential">The <see cref="Credential"/> to use.</param>
        public Connection(string server, ConnectionProtocol protocol, Credential credential)
        {
            Server = server;
            ConnectionProtocol = protocol;
            Credential = credential;
        }

        /// <summary>
        /// Creates a new instance of this class.
        /// </summary>
        public Connection()
        {
            Credential = new Credential();
        }
    }
}
